# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_seller, test_variants, test_uom, test_pricelist, test_product_pricelist
